#include <math.h>
#include <stdio.h>
#include <stdlib.h>

typedef struct {
  double x, y;
} Tocka;

typedef struct {
  Tocka s;
  double r;
} Kruznica;

double udalj_toc(const Tocka *t1, const Tocka *t2) {
  const double x = t2->x - t1->x, y = t2->y - t1->y;
  return sqrt(x * x + y * y);
}

int usp_kr(const Kruznica *k1, const Kruznica *k2) {
  static const Tocka ish = { 0.0, 0.0 };
  double d1, d2;
  if (k1 == k2)
    return 0;
  d1 = udalj_toc(&(k1->s), &ish);
  d2 = udalj_toc(&(k2->s), &ish);
  if (d1 < d2)
    return -1;
  if (d2 < d1)
    return 1;
  if (k1->r < k2->r)
    return -1;
  if (k2->r < k1->r)
    return 1;
  return 0;
}

int nadji(FILE *f, const Tocka *sred) {
  static const Tocka ish = { 0.0, 0.0 };
  int left, right, half;
  const double d1 = udalj_toc(sred, &ish);
  double d2 = -1.0;
  Kruznica k;
  (void)fseek(f, 0l, SEEK_END);
  left = 0;
  right = (int)(ftell(f) / sizeof(Kruznica)) - 1;
  while (left <= right) {
    half = left + (right - left) / 2;
    (void)fseek(f, half * sizeof(Kruznica), SEEK_SET);
    (void)fread(&k, sizeof(Kruznica), 1, f);
    d2 = udalj_toc(&(k.s), &ish);
    if (d1 < d2)
      right = half - 1;
    else if (d2 < d1)
      left = half + 1;
    else
      break;
  }
  if (d1 != d2) {
    (void)fseek(f, 0l, SEEK_END);
    return EOF;
  }
  while (half > 0) {
    (void)fseek(f, --half * sizeof(Kruznica), SEEK_SET);
    (void)fread(&k, sizeof(Kruznica), 1, f);
    if (d1 != udalj_toc(&(k.s), &ish)) {
      ++half;
      break;
    }
  }
  (void)fseek(f, half * sizeof(Kruznica), SEEK_SET);
  return half;
}

int sortiraj(FILE *f) {
  int len, srt, cnt = 1, end, i;
  Kruznica wnd[3];
  (void)fseek(f, 0l, SEEK_END);
  len = (int)(ftell(f) / sizeof(Kruznica));
  do {
    srt = 1;
    end = len - cnt;
    rewind(f);
    for (i = 0; i < end; ++i) {
      (void)fread(wnd, sizeof(Kruznica), 2, f);
      if (usp_kr(wnd + 0, wnd + 1) > 0) {
	wnd[2] = wnd[0];
	wnd[0] = wnd[1];
	wnd[1] = wnd[2];
	(void)fseek(f, -2l * sizeof(Kruznica), SEEK_CUR);
	(void)fwrite(wnd, sizeof(Kruznica), 2, f);
	srt = 0;
      }
      (void)fseek(f, -1l * sizeof(Kruznica), SEEK_CUR);
    }
    if (srt)
      rewind(f);
    else
      ++cnt;
  } while (!srt);
  return len;
}

int main() {
  /* Napisati za DZ... */
  return EXIT_SUCCESS;
}
